[![Build Status](https://travis-ci.com/TheTesla/dnsuptools.svg?branch=master)](https://travis-ci.com/TheTesla/dnsuptools)

# DNSupTools

This is a python library enabling easy dns server record updates. Currently only
inwx.de is supported.

This program library depends on pycurl. To use this you need:

```bash
sudo apt install libcurl4-openssl-dev libssl-dev
```

# Author

Stefan Helmert


